==> pvfs-1.5.6.tgz: pvfs-1.5.6/lib/pvfs_truncate64.c <==
/*
 * (C) 1995-2001 Clemson University and Argonne National Laboratory.
 *
 * See COPYING in top-level directory.
 */


#include <lib.h>
#include <meta.h>
#include <errno.h>

extern int pvfs_checks_disabled;

int pvfs_truncate64(const char *path, int64_t length)
{
	int i, s;
	mreq request;
	mack ack;
	struct sockaddr *saddr;
	char *fn;
	int64_t fs_ino, f_ino;

	memset(&request, 0, sizeof(request));
	if (!path) {
		errno = EFAULT;
		return(-1);
	}
	
	/* sticking to 32-bit for UNIX for now... */
	if (pvfs_checks_disabled) {
#ifndef LARGE_FILE_SUPPORT
		if ((off_t) length == length) {
			return truncate(path, (off_t) length);
		}
		else {
			errno = EINVAL;
			return(-1);
		}
#else
		return truncate64(path, length);
#endif
	}

	/* check to see if file is a pvfs file */
	if ((i = pvfs_detect(path, &fn, &saddr, &fs_ino, &f_ino)) != 1) {
		if (i < 0) {
			errno = ENOENT;
			return(-1);
		}
		if (i == 2) {
			errno = EISDIR;
			return(-1);
		}
#ifndef LARGE_FILE_SUPPORT
		if ((off_t) length == length) {
			return truncate(path, (off_t) length);
		}
		else {
			errno = EINVAL;
			return(-1);
		}
#else
		return truncate64(path, length);
#endif
	}

	/* Prepare request for file system  */
	request.uid = getuid();
	request.gid = getgid();
	request.type = MGR_TRUNCATE;
	request.dsize = strlen(fn);
	request.req.truncate.length = length;

	/* Send request to mgr */	
	if ((s = send_mreq_saddr(saddr, &request, fn, &ack)) < 0) {
		PERROR("send_mreq");
		return(-1);
	}

	return(0);
}

/*
 * Local variables:
 *  c-indent-level: 3
 *  c-basic-offset: 3
 *  tab-width: 3
 *
 * vim: ts=3
 * End:
 */

==> pvfs-1.6.1-pre1.tgz: pvfs-1.6.1-pre1/lib/pvfs_truncate64.c <==
/*
 * (C) 1995-2001 Clemson University and Argonne National Laboratory.
 *
 * See LIBRARY_COPYING in top-level directory.
 */


#include <lib.h>
#include <meta.h>
#include <errno.h>

extern int pvfs_checks_disabled;

int pvfs_truncate64(const char *path, int64_t length)
{
	int i, s;
	mreq request;
	mack ack;
	struct sockaddr *saddr;
	char *fn;
	int64_t fs_ino, f_ino;

	memset(&request, 0, sizeof(request));
	if (!path) {
		errno = EFAULT;
		return(-1);
	}
	
	/* sticking to 32-bit for UNIX for now... */
	if (pvfs_checks_disabled) {
#ifndef LARGE_FILE_SUPPORT
		if ((off_t) length == length) {
			return truncate(path, (off_t) length);
		}
		else {
			errno = EINVAL;
			return(-1);
		}
#else
		return truncate64(path, length);
#endif
	}

	/* check to see if file is a pvfs file */
	if ((i = pvfs_detect(path, &fn, &saddr, &fs_ino, &f_ino, FOLLOW_LINK)) != 1) {
		if (i < 0) {
			errno = ENOENT;
			return(-1);
		}
		if (i == 2) {
			errno = EISDIR;
			return(-1);
		}
#ifndef LARGE_FILE_SUPPORT
		if ((off_t) length == length) {
			return truncate(path, (off_t) length);
		}
		else {
			errno = EINVAL;
			return(-1);
		}
#else
		return truncate64(path, length);
#endif
	}

	/* Prepare request for file system  */
	request.uid = getuid();
	request.gid = getgid();
	request.type = MGR_TRUNCATE;
	request.dsize = strlen(fn);
	request.req.truncate.length = length;

	/* Send request to mgr */	
	if ((s = send_mreq_saddr(saddr, &request, fn, &ack)) < 0) {
		PERROR("send_mreq");
		return(-1);
	}

	return(0);
}

/*
 * Local variables:
 *  c-indent-level: 3
 *  c-basic-offset: 3
 *  tab-width: 3
 *
 * vim: ts=3
 * End:
 */
